Bibliography
============

.. bibliography:: bibliography.bib
    :all:

Indirect References
-------------------

Some extra references used in the codebase but not directly part of the public api:

- :cite:`Centore2014k`
- :cite:`Centore2014l`
- :cite:`Centore2014m`
- :cite:`Centore2014n`
- :cite:`Centore2014o`
- :cite:`Centore2014p`
- :cite:`Centore2014q`
- :cite:`Centore2014r`
- :cite:`Centore2014s`
- :cite:`Centore2014t`
- :cite:`Centore2014u`
- :cite:`CIETC1-382005h`
- :cite:`DJI2017`
- :cite:`FiLMiCInc2017`
- :cite:`Hanbury2003`
- :cite:`Houston2015a`
- :cite:`Laurent2012a`
- :cite:`MacAdam1935a`
- :cite:`Macadam1942`
- :cite:`Morovic2000`
- :cite:`MunsellColorSciencec`
- :cite:`Pointer1980a`
- :cite:`RenewableResourceDataCenter2003a`
- :cite:`Sharma2005b`
- :cite:`Siragusano2018a`
- :cite:`Susstrunk2000`
- :cite:`TheAcademyofMotionPictureArtsandSciences2020`
- :cite:`Ward2002`
- :cite:`Ward2016`
- :cite:`Wyszecki2000`
- :cite:`Wyszecki2000bb`
- :cite:`Wyszecki2000bh`
- :cite:`Wyszecki2000x`
